@@ -82,7 +82,7 @@ class KCONTACTS_EXPORT Addressee
     Q_PROPERTY(QString prefix READ prefix WRITE setPrefix)
     Q_PROPERTY(QString suffix READ suffix WRITE setSuffix)
     Q_PROPERTY(QString nickName READ nickName)
-    Q_PROPERTY(QDateTime birthday READ birthday) // ### can't set this due to withTime argument
+    Q_PROPERTY(QDateTime birthday READ birthday WRITE setBirthdayProperty) // special write method due to withTime argument
     Q_PROPERTY(bool birthdayHasTime READ birthdayHasTime)
     Q_PROPERTY(QString mailer READ mailer WRITE setMailer)
     Q_PROPERTY(KContacts::Geo geo READ geo WRITE setGeo)
@@ -919,6 +919,14 @@ public:
      */
     void removeAddress(const Address &address);
 
+    /**
+      Set the addressee
+
+      @param addresses The new addresses
+      @since 5.100
+     */
+    void setAddresses(const Address::List &addresses);
+
     /**
       Return address, which matches the given type.
 
@@ -1213,14 +1221,15 @@ public:
     void setSpousesName(const QString &spousesName);
 
 private:
-    QVariantList emailsVariant() const;
-    void setEmailsVariant(const QVariantList &emails);
-    QVariantList phoneNumbersVariant() const;
-    void setPhoneNumbersVariant(const QVariantList &emails);
-    QVariantList addressesVariant() const;
-    QVariantList urlsVariant() const;
-    QVariantList imppsVariant() const;
-    void setImppsVariant(const QVariantList &impps);
+    KCONTACTS_NO_EXPORT void setBirthdayProperty(const QDateTime &birthday);
+    KCONTACTS_NO_EXPORT QVariantList emailsVariant() const;
+    KCONTACTS_NO_EXPORT void setEmailsVariant(const QVariantList &emails);
+    KCONTACTS_NO_EXPORT QVariantList phoneNumbersVariant() const;
+    KCONTACTS_NO_EXPORT void setPhoneNumbersVariant(const QVariantList &emails);
+    KCONTACTS_NO_EXPORT QVariantList addressesVariant() const;
+    KCONTACTS_NO_EXPORT QVariantList urlsVariant() const;
+    KCONTACTS_NO_EXPORT QVariantList imppsVariant() const;
+    KCONTACTS_NO_EXPORT void setImppsVariant(const QVariantList &impps);
 
     class Private;
     QSharedDataPointer<Private> d;
