@@ -9,11 +9,17 @@
 #define NICKNAME_H
 
 #include "kcontacts_export.h"
+
+#include <QMap>
 #include <QSharedDataPointer>
 #include <QString>
-#include <QMap>
 
-namespace KContacts {
+class NickNameTest;
+
+namespace KContacts
+{
+class ParameterMap;
+
 /** @short Class that holds a NickName for a contact.
  *  @since 5.3
  */
@@ -21,6 +27,9 @@ class KCONTACTS_EXPORT NickName
 {
     friend KCONTACTS_EXPORT QDataStream &operator<<(QDataStream &, const NickName &);
     friend KCONTACTS_EXPORT QDataStream &operator>>(QDataStream &, NickName &);
+    friend class VCardTool;
+    friend class ::NickNameTest;
+
 public:
     NickName();
     NickName(const NickName &other);
@@ -35,8 +44,22 @@ public:
 
     Q_REQUIRED_RESULT bool isValid() const;
 
+#if KCONTACTS_ENABLE_DEPRECATED_SINCE(5, 88)
+    /**
+     * @deprecated Since 5.88 for lack of usage
+     */
+    KCONTACTS_DEPRECATED_VERSION(5, 88, "For lack of usage.")
     void setParameters(const QMap<QString, QStringList> &params);
-    Q_REQUIRED_RESULT QMap<QString, QStringList> parameters() const;
+#endif
+
+#if KCONTACTS_ENABLE_DEPRECATED_SINCE(5, 88)
+    /**
+     * @deprecated Since 5.88 for lack of usage
+     */
+    Q_REQUIRED_RESULT
+    KCONTACTS_DEPRECATED_VERSION(5, 88, "For lack of usage.")
+    QMap<QString, QStringList> parameters() const;
+#endif
 
     Q_REQUIRED_RESULT bool operator==(const NickName &other) const;
     Q_REQUIRED_RESULT bool operator!=(const NickName &other) const;
@@ -44,7 +67,12 @@ public:
     NickName &operator=(const NickName &other);
 
     Q_REQUIRED_RESULT QString toString() const;
+
 private:
+    // exported for NickNameTest
+    void setParams(const ParameterMap &params);
+    Q_REQUIRED_RESULT ParameterMap params() const;
+
     class Private;
     QSharedDataPointer<Private> d;
 };
