@@ -1,26 +1,14 @@
 /*
     This file is part of the KContacts framework.
-    Copyright (c) 2001 Cornelius Schumacher <schumacher@kde.org>
+    SPDX-FileCopyrightText: 2001 Cornelius Schumacher <schumacher@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "phonenumber.h"
+#include "parametermap_p.h"
 
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 #include <krandom.h>
 
 #include <QDataStream>
@@ -53,7 +41,7 @@ public:
     QString mId;
     QString mNumber;
     Type mType;
-    QMap<QString, QStringList> mParameters;
+    ParameterMap mParamMap;
 };
 
 PhoneNumber::PhoneNumber()
@@ -90,7 +78,7 @@ bool PhoneNumber::operator==(const PhoneNumber &other) const
         return false;
     }
 
-    if (d->mParameters != other.d->mParameters) {
+    if (d->mParamMap != other.d->mParamMap) {
         return false;
     }
 
@@ -148,7 +136,6 @@ QString PhoneNumber::normalizedNumber() const
     return result;
 }
 
-
 void PhoneNumber::setType(Type type)
 {
     d->mType = type;
@@ -169,7 +156,7 @@ PhoneNumber::TypeList PhoneNumber::typeList()
     static TypeList list;
 
     if (list.isEmpty()) {
-        list << Home << Work << Msg << Pref << Voice << Fax << Cell << Video
+        list << Home << Work << Msg << Pref << Voice << Fax << Cell << Video //
              << Bbs << Modem << Car << Isdn << Pcs << Pager << Undefined;
     }
 
@@ -241,12 +228,9 @@ QString PhoneNumber::typeLabel(Type type)
     }
 
     const TypeList list = typeList();
-
-    TypeList::ConstIterator it;
-    TypeList::ConstIterator end(list.constEnd());
-    for (it = list.constBegin(); it != end; ++it) {
+    for (const auto f : list) {
         // these are actually flags
-        const TypeFlag flag = static_cast<TypeFlag>(static_cast<int>(*it));
+        const TypeFlag flag = static_cast<TypeFlag>(static_cast<int>(f));
         if (type & flag) {
             if (!first) {
                 label.append(QLatin1Char('/'));
@@ -278,42 +262,49 @@ QString PhoneNumber::toString() const
     QString str = QLatin1String("PhoneNumber {\n");
     str += QStringLiteral("    Id: %1\n").arg(d->mId);
     str += QStringLiteral("    Type: %1\n").arg(typeLabel(d->mType));
-    if (!d->mParameters.isEmpty()) {
-        QString param;
-        QMap<QString, QStringList>::const_iterator it = d->mParameters.constBegin();
-        const QMap<QString, QStringList>::const_iterator end = d->mParameters.constEnd();
-        while (it != end) {
-            param += QStringLiteral("%1 %2").arg(it.key(), it.value().join(QLatin1Char(',')));
-            ++it;
-        }
-        str += QStringLiteral("    parameters: %1\n").arg(param);
-    }
+    str = d->mParamMap.toString();
     str += QStringLiteral("    Number: %1\n").arg(d->mNumber);
     str += QLatin1String("}\n");
 
     return str;
 }
 
+#if KCONTACTS_BUILD_DEPRECATED_SINCE(5, 88)
 void PhoneNumber::setParameters(const QMap<QString, QStringList> &params)
 {
-    d->mParameters = params;
+    d->mParamMap = ParameterMap::fromQMap(params);
 }
+#endif
 
+#if KCONTACTS_BUILD_DEPRECATED_SINCE(5, 88)
 QMap<QString, QStringList> PhoneNumber::parameters() const
 {
-    return d->mParameters;
+    return d->mParamMap.toQMap();
+}
+#endif
+
+void PhoneNumber::setParams(const ParameterMap &params)
+{
+    d->mParamMap = params;
+}
+
+ParameterMap PhoneNumber::params() const
+{
+    return d->mParamMap;
 }
 
 QDataStream &KContacts::operator<<(QDataStream &s, const PhoneNumber &phone)
 {
-    return s << phone.d->mId << (uint)phone.d->mType << phone.d->mNumber << phone.d->mParameters;
+    return s << phone.d->mId << static_cast<uint>(phone.d->mType) << phone.d->mNumber << phone.d->mParamMap;
 }
 
 QDataStream &KContacts::operator>>(QDataStream &s, PhoneNumber &phone)
 {
     uint type;
-    s >> phone.d->mId >> type >> phone.d->mNumber >> phone.d->mParameters;
+    s >> phone.d->mId >> type >> phone.d->mNumber >> phone.d->mParamMap;
     phone.d->mType = PhoneNumber::Type(type);
 
     return s;
 }
+
+#include "moc_phonenumber.cpp"
